@@ -6,7 +6,7 @@ use Mojo::Util 'dumper';
 use Sentry::Client;
 use Sentry::Hub;
 
-our $VERSION = version->declare('0.10.5');
+our $VERSION = version->declare('0.11.0');
 
 sub _call_on_hub ($method, @args) {
   my $hub = Sentry::Hub->get_current_hub();
@@ -98,7 +98,7 @@ Sentry::SDK - sentry.io integration
 
 =head2 init
 
-  Sentry::SDK->init(%options);
+  Sentry::SDK->init(\%options);
 
 Initializes the Sentry SDK in your app. The following options are provided:
 
